Patched Kitchen Method
======================
This package exists exclusively to patch a single method in the highly useful `Kitchen package <https://pypi.org/project/kitchen/>`_.

The method was originally developed for use in the `ProcessRunner <https://pypi.org/project/processrunner/>`_ package, thus the "ProcessRunner-KitchenPatch" naming convention.

License
=======
Kitchen was originally released under the LGPL license, and thus this package is as well.